from logstash.formatter import LogstashFormatterVersion1


class Formatter(LogstashFormatterVersion1):

    def format(self, record):
        # Create message dict
        message = {
            '@timestamp': self.format_timestamp(record.created),
            '@version': '1',
            'host': self.host,
            'pathname': record.pathname,
            'tags': self.tags,
            'msg': record.getMessage(),

            # Extra Fields
            'level': record.levelname,
            'logger_name': record.name,
        }

        # Add extra fields
        message.update(self.get_extra_fields(record))

        # If exception, add debug info
        if record.exc_info:
            message.update(self.get_debug_fields(record))

        return self.serialize(message)



from setuptools import setup, find_packages

install_requires = [
    'python-logstash==0.4.6',
]


setup(
    name="mv-logger",
    version='0.0.3',
    license='MIT',
    author_email='kontakt@mobilevikings.pl',
    author='Mobile Vikings PL',
    description='mv-logger',
    url='https://github.com/willard-ag/mv-logger',
    long_description=open('README.md', 'r').read(),
    packages=find_packages('.'),
    install_requires=install_requires,
    classifiers=[
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Operating System :: OS Independent',
        'Environment :: Web Environment',
    ],
)
